"use strict";
const mqtt_1 = require("./mqtt");
let hap;
class ShellyDimmer {
    constructor(log, config, api) {
        this.log = log;
        this.name = config.name;
        this.api = api;
        //Get MQTT-Information
        this.deviceid = config.device;
        this.host = config.host;
        this.port = config.port;
        if (config.user == undefined)
            this.user = "";
        else
            this.user = config.user;
        if (config.password == undefined)
            this.password = "";
        else
            this.password = config.password;
        this.lightbulbService = new hap.Service.Lightbulb(this.name);
        this.lightbulbService
            .getCharacteristic(hap.Characteristic.On)
            .onGet(this.getOnHandler.bind(this))
            .onSet(this.setOnHandler.bind(this));
        this.lightbulbService
            .getCharacteristic(hap.Characteristic.Brightness)
            .onGet(this.getBrightnessHandler.bind(this))
            .onSet(this.setBrightnessHandler.bind(this));
        this.informationService = new hap.Service.AccessoryInformation()
            .setCharacteristic(hap.Characteristic.Manufacturer, "Pascal Berski")
            .setCharacteristic(hap.Characteristic.SerialNumber, this.deviceid)
            .setCharacteristic(hap.Characteristic.Model, "ShellyDimmer 2");
        this.mqtt = new mqtt_1.MqttController(this.log, this.lightbulbService, this.api, this.host, this.port, this.user, this.password, this.deviceid);
        log.info("ShellyDimmer2 (" + this.name + ") finished initializing!");
    }
    getServices() {
        return [this.informationService, this.lightbulbService];
    }
    async getOnHandler() {
        return this.mqtt.getOn();
    }
    async setOnHandler(value) {
        this.mqtt.setOn(value);
    }
    async getBrightnessHandler() {
        return this.mqtt.getBrightness();
    }
    async setBrightnessHandler(value) {
        this.mqtt.setBrightness(value);
    }
}
module.exports = (api) => {
    hap = api.hap;
    api.registerAccessory("MQTTShellyDimmer2", ShellyDimmer);
};
//# sourceMappingURL=accessory.js.map