"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MqttController = void 0;
const mqtt_1 = require("mqtt");
class MqttController {
    constructor(log, lightbulbService, api, host, port, user, password, deviceid) {
        this.log = log;
        this.host = host;
        this.port = port;
        this.user = user;
        this.password = password;
        this.deviceid = deviceid;
        this.on = false;
        this.brightness = 50;
        this.api = api;
        this.lightbulbService = lightbulbService;
        this.client = mqtt_1.connect("mqtt://" + this.host + ":" + this.port, {
            username: this.user,
            password: this.password,
        });
        const subString = "shellies/shellydimmer2-" + this.deviceid + "/light/0/status";
        this.client.subscribe(subString);
        this.client.on("message", (topic, message) => {
            //this.log.info("Topic: " + topic + "; Message: " + message);
            this.Update(message);
        });
    }
    send(topic, message) {
        this.client.publish(topic, message);
    }
    Update(message) {
        const json = JSON.parse(message.toString());
        this.on = json.ison;
        this.brightness = json.brightness;
        this.lightbulbService
            .getCharacteristic(this.api.hap.Characteristic.On)
            .updateValue(this.on);
        this.lightbulbService
            .getCharacteristic(this.api.hap.Characteristic.Brightness)
            .updateValue(this.brightness);
    }
    getBrightness() {
        return this.brightness;
    }
    getOn() {
        return this.on;
    }
    setBrightness(value) {
        this.send("shellies/shellydimmer2-" + this.deviceid + "/light/0/set", '{"brightness": ' + value + "}");
    }
    setOn(value) {
        if (value)
            this.send("shellies/shellydimmer2-" + this.deviceid + "/light/0/command", "on");
        else
            this.send("shellies/shellydimmer2-" + this.deviceid + "/light/0/command", "off");
    }
}
exports.MqttController = MqttController;
//# sourceMappingURL=mqtt.js.map